<?php
namespace Themes\kbgolf\pro\app\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Support\Facades\Redirect;
use SocialiteProviders\Apple\Provider;
use Laravel\Socialite\Facades\Socialite;
use Laravel\Socialite\Two\GoogleProvider;
use Laravel\Socialite\Two\FacebookProvider;
use SocialiteProviders\Kakao\KakaoProvider;
use App\Providers\Socialite\OAuth2\DaboryProvider;
use App\Services\AppleTokenService;
use SocialiteProviders\Naver\Provider as NaverProvider;
use Illuminate\Http\Request;

class SocialTalkController extends Controller
{
    private $appleTokenService;
    private $callApiService;
    private $oauth2Info;
    private $target;

    public function __construct(CallApiService $callApiService, AppleTokenService $appleTokenService)
    {
        $this->callApiService = $callApiService;
        $this->appleTokenService = $appleTokenService;
    }

    public function redirectToProvider($provider)
    {
        $this->oauth2Info = request('oauth2Info');
        // [$this->target, $ssoBrand] = explode('-', $provider);

        $brandCode = 'member-'.$provider;
        $response = $this->callApiService->callApi([
            'url' => 'setup-page',
            'data' => [
                'PageVars' => [
                    'Query' => "(setup_code = 'sso-client' and brand_code = '{$brandCode}') and is_on_use = '1'",
                    'Limit' => 100
                ]
            ],
        ]);
        // dd($this->oauth2Info);
        // dd($response);
        if (!empty($response['Page'])) {
            $setupJson = $response['Page'][0]['SetupJson'];
            // dd($setupJson);
            $setupArray = json_decode($setupJson, true);
            $redirectUri = route('social.login', ['provider' => $brandCode]);
            if (json_last_error() === JSON_ERROR_NONE) {
                $clientId = $setupArray['ClientId'] ?? null;
                // dd($clientId);
            }
        }

        if ($provider == 'naver') {
            $url = 'https://nid.naver.com/oauth2.0/authorize?' . http_build_query([
                'response_type' => 'code',
                'client_id' => $clientId,
                'redirect_uri' => $redirectUri,
                'state' => csrf_token(),
            ]);
        } elseif ($provider == 'kakao') {
            $url = 'https://kauth.kakao.com/oauth/authorize?' . http_build_query([
                'response_type' => 'code',
                'client_id' => $clientId,
                'redirect_uri' => $redirectUri,
                'state' => csrf_token(),
            ]);
        }
        // dd($url);
        return redirect($url);
    }

    public function login($provider)
    {
        // dd($provider);
        [$this->target, $ssoBrand] = explode('-', $provider);
        if ($this->target == 'member') {
            if ($ssoBrand == 'naver') {
                // return Redirect::away('https://talk.naver.com/ct/w5u3g9');
                echo "<script>window.open('https://talk.naver.com/ct/w5u3g9', '_blank', 'width=600,height=600');</script>";
                return;
            }elseif($ssoBrand == 'kakao'){
                echo "<script>window.open('https://pf.kakao.com/_aAAGj/chat', '_blank', 'width=600,height=600');</script>";
                return;
                // return Redirect::away('https://pf.kakao.com/_aAAGj/chat');
            }
        }
    }

    public function setConfig($provider, $target)
    {
        $config = [
            'client_id' => $this->oauth2Info['ClientId'],
            'client_secret' => $this->oauth2Info['ClientSecret'],
            'redirect' => "/social/$target-$provider/callback"
        ];

        switch ($provider) {
            case 'dabory':
                $driver = Socialite::buildProvider(DaboryProvider::class, [
                    'client_id' => config('app.api.main.ClientId'),
                    'client_secret' => config('app.api.main.ClientSecret'),
                    'redirect' => $config['redirect']
                ]);
                break;
            case 'facebook':
                $driver = Socialite::buildProvider(FacebookProvider::class, $config);
                break;
            case 'kakao':
                $driver = Socialite::buildProvider(KakaoProvider::class, $config);
                break;
            case 'google':
                $driver = Socialite::buildProvider(GoogleProvider::class, $config);
                break;
            case 'naver':
                $driver = Socialite::buildProvider(NaverProvider::class, $config);
                break;
            case 'apple':

                $config['client_secret'] = $this->appleTokenService->generate(
                    $this->oauth2Info['PrivateKey'],
                    $this->oauth2Info['ClientId'],
                    $this->oauth2Info['TeamId'],
                    $this->oauth2Info['KeyId'],
                );

                $driver = Socialite::buildProvider(Provider::class, $config);
                break;
        }
        return $driver;
    }
}
